# cglearn

"cglearn" is a Python library that aims to spark probabilistic reasoning and analysis via chain graphs.

Developers: Mohammad Ali Javidian, Shantanu Deore

You can visit https://majavid.github.io/cglearnDOCs/ for details of the documentation.
